module.exports = defineTest({
	description: 'handles dynamic imports containing dynamic imports',
	options: {
		input: 'main'
	}
});
